// eslint-disable-next-line @typescript-eslint/no-unsafe-assignment
const abortSignalAnyBuiltIn = Object.hasOwn(AbortSignal, "any")
    ? // @ts-expect-error(ndhoule): Not supported in older versions of TS/some older environments
        AbortSignal.any
    : undefined;
const abortSignalAnyPolyfill = (signalsIter) => {
    const signals = Array.from(signalsIter);
    if (signals.length === 1) {
        return signals[0];
    }
    const controller = new AbortController();
    for (const signal of signals) {
        if (signal.aborted) {
            controller.abort(signal.reason);
            break;
        }
        signal.addEventListener("abort", () => {
            controller.abort(signal.reason);
        }, { once: true, signal: controller.signal });
    }
    return controller.signal;
};
/**
 * `abortSignalAny` is a polyfill for AbortSignal#any.
 *
 * https://developer.mozilla.org/en-US/docs/Web/API/AbortSignal/any_static
 */
export const abortSignalAny = abortSignalAnyBuiltIn !== null && abortSignalAnyBuiltIn !== void 0 ? abortSignalAnyBuiltIn : abortSignalAnyPolyfill;
//# sourceMappingURL=abort_signal_any.js.map